# Et0calc_function_Swe_3.r; 
# Calculating Et0 from standard meteorological variables - in case pan not there
#ollexxl@live.se from Thomas Ktterer & Allen et al.FAO
# This is to use Swedish data base weather data
# See Allen etal 1998, Crop evapotranspiration - Guidelines for computing  # crop water requirements - FAO Irrigation and drainage paper 56. 
#The data file swedclim.csv Has the variables: datum  Temperature	Humidity	Windspeed	Precipitation	Cloudiness
# First Et0 is calculated from these, since pan missing - this is not an exact method

###############################################################################
#Note: Allen et recommends Et0 from pan evaporation (Penman).Many other options
# there to calculate from other variables as done below. Not recommended without 
# calibrating against, e.g., monthly pan evaporation 

#Read infile and set names
News=read.csv("Swedclim.csv"); Date=News[,1];Temperature=News[,2]; Humidity=News[,3];Windspeed=News[,4];Precipitation=News[,5];
Cloudiness=News[,6];Dummy=News[,7]
News$Dummy <- NULL # Delete Dummy
Date=format(Date, format = "") 
Date=as.Date(Date, format="%Y%m%d")
Size <- nrow(News)#number of rows read in - check skip
Yr=as.numeric(format(Date, format = "%Y"));# Extract year
Day=as.numeric(format(Date, format = "%j"));# Julian day

# For each station NOTE!!!!!!!
altitude=10; #m asl;
latitude=59.82; # NOT checked for 5a
longitude=10
station="5a"

# In:Temperature,Humidity,Windspeed,Precipitation,Cloudiness,altitude,longitude,latitude,station
#SweEt0 calculates Et0 using these according to Allen et al.
SweEt0 <- function(Temperature,Humidity,Windspeed,Precipitation,Cloudiness,altitude,longitude,latitude,station){
vind2m =Windspeed*4.87/(log(67.8*10-5.42));     
P=101.3*((293-0.0065*altitude)/293)^5.26; lambda=2.45; cp=0.001013; epsilon=0.622;gamma=cp*P/(epsilon*lambda); #eq8;
es=0.6108*exp(17.27*Temperature/(Temperature+237.3)); ea=Humidity/100*es; vpd=es-ea;
Gsc=0.082; pi=3.141592654; dr=1+0.033*cos(2*pi/365*Day);  de=0.409*sin(2*pi/365*Day-1.39); radians=pi/180*latitude;  #eq22;
ws=acos(-tan(radians)*tan(de));  Ra= 24*60/pi*Gsc*dr*(ws*sin(radians)*sin(de)+cos(radians)*cos(de)*sin(ws));    #eq21;
Radevap=Ra/lambda; Daylight=24/pi*ws;  Sunlight=1-Cloudiness; 
Rs=(0.25+0.5*Sunlight)*Ra;  Rso=(0.75+0.00002*altitude)*Ra;  
Albedo=0.23;
Rns=(1-Albedo)*Rs;  TmeanK=273.15+Temperature; SBolz=4.903*10^(-9);RsRso=Rs/Rso;
big <- (RsRso > 1); RsRso[big] <- 1 # Replaces > 1 with 1
Rnl=SBolz*TmeanK^4*(0.34-0.14*ea^0.5)*(1.35*RsRso-0.35); #eq39;
Rn=Rns-Rnl;tmp=Rs/Rso
Delta=(4098*(0.6108*exp(17.27*Temperature/(Temperature+237.3)))/((Temperature+237.3)^2));  
Etotal=0.408*Delta*Rn + gamma*900/(Temperature+273)*vind2m*vpd; #eq6 page 65;
Etonam=Delta+gamma*(1+0.34*vind2m); #eq6 page 65;
Et0= Etotal/ Etonam; 
simout <- data.frame(Temperature,Humidity,Windspeed,Precipitation,Cloudiness,altitude,longitude,latitude,station, Et0)
return(simout)}
#Call function
result1 <- SweEt0(Temperature,Humidity,Windspeed,Precipitation,Cloudiness,altitude,longitude,latitude,station)

# Plotting etc.
windows(10,5)
par( mfrow = c( 3, 1 ))
plot(Date,result1$Et0,type="l", main="Et0 Central Sweden")
Anntemp=by(result1$Temperature, Yr, mean) #Annual mean by year
Yrr=by(Yr, Yr, mean) #One average year per year
plot(Yrr,Anntemp,type="h", main="Annual mean temperature")
AnnEt0=by(result1$Et0, Yr, mean) #Annual mean by year
Yrr=by(Yr, Yr, mean) #One average year per year
plot(Yrr,AnnEt0,type="h", main="Annual mean daily Et0")
