#  ICBM as function 20131009-
# v. 2 www.oandren.com
# Parameters & state equations, see also www.oandren.com
# Change i, re and h and set inital Y and O

#Define ICBM function
ICBM <- function(re, i, kY, kO, h, Y0, O0, time){
  Oss <- (h*i)/(re*kO) ; Yss <- i/(re*kY) ;Y <- i/(kY*re) + (Y0-i/(kY*re))*exp(-kY*re*time);
  O <- (O0 - i*kY*h*re/(kY*re*kO*re) - kY*h*re*Y0/(kO*re-kY*re) + i*kY*h*re/(kY*re*(kO*re-kY*re)))*exp(-kO*re*time) + 
    i*kY*h*re/(kY*re*kO*re) + (kY*h*re*Y0/(kO*re-kY*re))*exp(-kY*re*time) - (i*kY*h*re/(kY*re*(kO*re-kY)))*exp(-kY*re*time);
  Tot <- Y+O
  return(data.frame(re,i,kY,kO,h,Y0,O0,Oss,Yss,Y,O,Tot,time))
}
#Initial set of variables
re <- 1.0 ; i <- 0.4 ; kY <- 0.8 ; kO <- 0.006 ; h <- 0.12
Y0 <- 0.4 ; O0 <- 8 ; time <- 0:29 # 30 yrs

#Make data frame 
Out1 <- ICBM(re, i, kY, kO, h, Y0, O0, time) #Call ICBM with default parms

#run with double re
Out2 <- ICBM(2.0, i, kY, kO, h, Y0, O0, time)

#run with double re&i
Out3 <- ICBM(2.0, 0.8, kY, kO, h, Y0, O0, time)

#run with half re
Out4 <- ICBM(0.5, i, kY, kO, h, Y0, O0, time)
#plot (time,Y)
# plot (time, O)
windows(width=50,height=25) # new plot window
par( mfrow = c( 2, 2 ))
#1
plot (Out1$time, Out1$Tot, type='l', main = bquote(ICBM~ "re ="~.(Out1$re)),xlab='Time (years)',ylab='Mass (g)',
      yaxs='i',sub=bquote("i ="~.(Out1$i)),col='red',lwd='3',ylim=c(0,10), yaxp=c(0,10,10))
lines (Out1$time, Out1$O, type='l',col='blue')

legend("topleft", legend=c("Tot", "O"), 
       text.col=c('red','blue'),ncol=2)
#2
plot (Out2$time, Out2$Tot, type='l', main = bquote(ICBM~ "re ="~.(Out2$re)),xlab='Time (years)',ylab='Mass (g)',
      yaxs='i',sub=bquote("i ="~.(Out2$i)),col='red',lwd='3',ylim=c(0,10), yaxp=c(0,10,10))
lines (Out1$time, Out1$O, type='l',col='blue')

legend("topleft", legend=c("Tot", "O"), 
       text.col=c('red','blue'),ncol=2)
#3
plot (Out3$time, Out3$Tot, type='l', main = bquote(ICBM~ "re ="~.(Out3$re)),xlab='Time (years)',ylab='Mass (g)',
      yaxs='i',sub=bquote("i ="~.(Out3$i)),col='red',lwd='3',ylim=c(0,10), yaxp=c(0,10,10))
lines (Out3$time, Out1$O, type='l',col='blue')

legend("topleft", legend=c("Tot", "O"), 
       text.col=c('red','blue'),ncol=2)
#4
plot (Out4$time, Out4$Tot, type='l', main = bquote(ICBM~ "re ="~.(Out4$re)),xlab='Time (years)',ylab='Mass (g)',
      yaxs='i',sub=bquote("i ="~.(Out2$i)),col='red',lwd='3',ylim=c(0,10), yaxp=c(0,10,10))
lines (Out4$time, Out1$O, type='l',col='blue')

legend("topleft", legend=c("Tot", "O"), 
       text.col=c('red','blue'),ncol=2)

#cbind makes a matrix out of the variable vectors for printing etc
#outall=cbind(time,O,Y,Tot,re,i,kY,kO,h,Y0,O0,Oss,Yss)

#print.default(outall)
#export text file to be able to read into e.g. Excel
write.table(Out1,file="Out1.txt")
write.table(Out2,file="Out2.txt")
