#########################################################################
#  re_mother_v2.R  20130507-15 ollexxl@live.se www.oandren.com		#
#	v2 > set Et0 to >= 0								#
# Climate calculations for ICBM by Thomas Ktterer and Olof Andrn	#
# This R program is calibrated against re_mother_v1.sas			#
# which is the original based on Inc_WatMod_11.sas			#
# data set used: 30 yr of SLU Ultuna weather - for calibration		#
# Other programs of re calcs, e.g., in Excel				#
# should be compared with the outputs from here				#
# latest version at : www.oandren.com/ICBM				#
# TO DO: maybe prepare for GAI > 0					#
# This is not fully tested with crop, i.e., GAI > 0				#
# This R version does not have GAI calculations and				#
# calculations of Penman from other variables					#
# See SAS program for that								#
# Note this version resets Soil temp and water 1 Jan  change for 	#
# Tropical											#
#  See Allen et al. Crop evapotranspiration - 				#
# Guidelines for computing crop water requirements -			#
# FAO Irrigation and drainage paper 56					#	
# http://www.fao.org/docrep/X0490E/x0490e00.htm#Contents		#
# also calculate Et0 from other variables in SAS program		#
# and www.oandren.com and mail ollexxl@live.se				#
#									#
# and Andrn, O., Kihara, J., Bationo, A., Vanlauwe, B. and 		#
# Ktterer, T.  2007 Soil climate and decomposer activity 		#
# in sub-Saharan Africa, estimated from standard weather station data #
#  used in soil carbon balance calculations. Ambio 36:379-386. 	#
# based on SAS prog Inc_Watmod_11.sas					#
#########################################################################
#
#
#Read infile and set names
#News=read.table("Ult30yr_SAS_re.txt",nrows=730)#Read the infile - only 1st year###
News=read.table("Ult30yr_SAS_re.txt")#Read the infile###

 Date=as.Date(News[,1]);Day=News[,2];Temperature=News[,3];Precipitation=News[,4];
Et0=News[,5];recheck=News[,6]
# Et0 is reference crop evapotranspiration [mm day-1] = 0.7 * pan evaporation
#counting Rows in infile
Size <- nrow(News)#number of rows read in
Yr=as.numeric(format(Date, format = "%Y"));# Extract year 
#
# Define constants
# Set by user, initial values
L=300; #topsoil thickness, mm;
CF <- 1 #Correction factor depending on L, see Excel reclim###############
water0 <- 105.0 #Start water, mm Between twilt*L and tfield*L
Soiltemp0 <- 0 # Soiltemp at start

#Constants, usually constant (!)
tfield <- 0.35 # Field capacity of standard soil
twilt <- 0.22  # Wilting point of standard soil
GAI <- 0.0 #No vegetation, no green area
alfa <- 0.70 #twilt multiplier
Porosity <- 0.43 #Porosity of standard soil
bd <- 1.44	#bulk density 
rs <- 0.5 		#(bulk) surface or canopy resistance [s m-1]
rwp <- 0.15		#
s1 <- 0.95
s2 <- 0.40
LAI <- 0.0
LAIref <- 3.0
kz <- 0.017
klai <- 0.15
att <- 0.24
tmin <- -3.78
kc <- (1.3-0.5*exp(-0.17*GAI))# crop coefficient [-]
z <- L/20		# middle of soil layer (cm)
re_cult=1 # cultivation factor
topt <- min(tfield, 0.6*Porosity) #Optimum water for activity
#Variables
Inter <- rep(0,Size) 	#Interception
etc <- rep(0,Size) # crop evapotranspiration [mm day-1]
epot <- rep(0,Size) # Above, minus Intercepted
theta <- rep(0,Size) # Volumetric water fraction
water <- rep(water0,Size) # Water, mm
Kr <- rep(0,Size)#soil evaporation reduction coefficient [-]
actevapo <- rep(0,Size)# actual evaporation
re_wat <- rep(0,Size)# water activity factor
re_temp <- rep(0,Size)# temp. activity factor
reu <- rep(0,Size)#  activity factor
re <- rep(0,Size)#  activity factor, corrected
Soiltemp <- rep(0,Size)# soil temperature
Tsurface <- rep(0,Size)# soil surface
###


#Main loop#############################################################
for (t in 1:Size) {
#New in v.2
		if (Et0[t]<0) {
			Et0[t]=0
				}

	etc[t] = Et0[t]*kc
	Inter[t]=min(Precipitation[t],etc[t],0.2*GAI)
	epot[t] = etc[t]-Inter[t]
#1st day every year
if(Day[t] == 1) {
		 water0 = tfield*L 
		water[t] = water0
				theta[t]= water[t]/L
		Kr[t]= max(0,(1-(0.9*tfield-theta[t])/(0.9*tfield-alfa*twilt))^2)
	if(Kr[t]>1) { Kr[t]=1 }
	actevapo[t] = epot[t]*Kr[t]
	    }

#The Kr calculation is not perfect - same value the two first days...
#but we can live with that	
	
if(t > 1) {
	Kr[t]= max(0,(1-(0.9*tfield-theta[t-1])/(0.9*tfield-alfa*twilt))^2)

		if(Kr[t] > 1) {
			Kr[t] = 1
				}
	actevapo[t] = epot[t]*Kr[t]
		water[t]=water[t-1]+Precipitation[t]-(actevapo[t]+Inter[t])
#main water balance calc above
		if(water[t] <0) {
			water[t]=0
			}
		if(water[t] > tfield*L) {
			water[t]=tfield*L
			}
		theta[t]=water[t-1]/L #based on the previous day 
		}	
  #water response function ###
	if(theta[t] >= tfield) {
		theta[t] = tfield-0.00001
		}
	if(theta[t]>topt) {
		 re_wat[t]=(1-rs)*(theta[t]-topt)/(topt-Porosity)+1
				}
	if(theta[t]<twilt) {
		 re_wat[t]=rwp*theta[t]/twilt
				}
	if(twilt<=theta[t] & theta[t]<=topt) {
		 re_wat[t]=(1-rwp)*(theta[t]-twilt)/(topt-twilt)+rwp
				}
	if (re_wat[t]>1) {
		 re_wat[t]=1
				}
	if (re_wat[t]<0) {
		 re_wat[t]=0
				}
  #water response end ###
  # Soil temp & activity
	if (Temperature[t]<0) {
		Tsurface[t]=0.2*Temperature[t]
				}
	if (Temperature[t]>=0) {
		Tsurface[t]=Temperature[t]*(s1+(1-s1)*exp(-s2*(LAI-LAIref)))
				}
	if (Day[t]==1) {
		Soiltemp[t]=0
				}
	if (Day[t]>1) {
		Soiltemp[t]=Soiltemp[t-1] + (Tsurface[t] - Soiltemp[t-1])*att*exp(-kz*z)*exp(-klai*LAI)
				}
#Note: we reset 1 Jan every year in SAS####################
	re_temp[t]=((Soiltemp[t]-tmin)^2/((30-tmin))^2)
  #end soil temp
	reu[t]=re_temp[t]*re_wat[t]*re_cult
 	re[t]=reu[t]/CF
	#cat(t,re_wat[t],water[t],"\n");
	#cat(Et0[t],"\n")
 }
#End main loop #####################################################

#------------------------------------------------------------------

cor(recheck,re)
mean(re)
windows() # new plot window
plot(Date,re,col='black',type="l",main="re_clim 1970 Ult (mean=0.118R 0.120SAS)")
lines(Date,recheck,col='red')
mean(recheck)
Diff=re-recheck
windows() # new plot window
plot(Date,Diff,col='black',type="l",main="re_clim 1970 Ult (mean=0.)")
windows() # new plot window
plot(re,recheck,col='black',type="p",main="re_clim 1970 Ult (SAS vs R corr=0.999)")

reann=by(re, Yr, mean) #Annual mean by year
Yrr=by(Yr, Yr, mean) #One average year per year
windows() # new plot window
plot(Yrr,reann,col='black',type="l",main="re_clim 1970 Ult (mean=0.118R 0.120SAS)")
windows() # new plot window
plot(Date,Et0,col='black',type="p",main="re_clim 1970 Ult (mean=0.118R 0.120SAS)")
reann; Max=max(reann); Min=min(reann); Max; Min;

