/*
#########################################################################
#  re_mother_v2.sas  20130507-16 ollexxl@live.se www.oandren.com	#
# v2 with Et0 forced to be above or equal to zero				#
# Based on Inc_Watmod_11_reclim_fallow_1970-1999.sas			#
# OA 2030516 Deleted double statement water=tfield*L;			# 
# Climate calculations for ICBM by Thomas Ktterer and Olof Andrn	#
# This sas program is the base for re calibration			#
# data set used: 30 yr of SLU Ultuna weather - for calibration		#
# Other programs of re calcs, e.g., in Excel				#
# should be compared with the outputs from here				#
# latest version at : www.oandren.com/ICBM				#
# To do: maybe set Et0 to minimum = 0.					#
# This program is not fully tested with crop, i.e., GAI > 0		#
# Note this version resets Soil temp and water 1 Jan  change for 	#
# Tropical										#
#												#
#  See Allen et al. Crop evapotranspiration - 				#
# Guidelines for computing crop water requirements -			#
# FAO Irrigation and drainage paper 56					#	
# http://www.fao.org/docrep/X0490E/x0490e00.htm#Contents		#
# also calculate Et0 from other variables in SAS program		#
# and www.oandren.com and mail ollexxl@live.se				#
#									#
# and Andrn, O., Kihara, J., Bationo, A., Vanlauwe, B. and 		#
# Ktterer, T.  2007 Soil climate and decomposer activity 		#
# in sub-Saharan Africa, estimated from standard weather station data #
#  used in soil carbon balance calculations. Ambio 36:379-386. 	#
#########################################################################
*
*/
PROC IMPORT OUT= WORK.a 
            DATAFILE= "C:\MIR\thomk\ICBM\Olle2013\Ultuna56-99.xls" 
            DBMS=EXCEL2000 REPLACE;
     GETNAMES=YES;
RUN;


data calc1; set a;
GAImax=0; GAIbase=0; varians=800; 
twilt=0.22;
tfield=0.35;
porosity=0.43;
bd=1.44;
re_cult=1;
if year<1970 then delete;
if year>1999 then delete;

if cloudiness > 1 then cloudiness =1; *fix up database problem;
*Water calculations;
L=300; *topsoil thickness, mm;
altitude=10; *m asl;
latitude=59.82; 

************************************;

retain water0 soiltemp0;

* calculate penman=Eto from cloud etc;
vind2m =windspeed*4.87/(log(67.8*10-5.42));     *eq47;

*parameters;
P=101.3*((293-0.0065*altitude)/293)**5.26;    *eq7;
lambda=2.45;
cp=0.001013; 
epsilon=0.622;
gamma=cp*P/(epsilon*lambda); *eq8;

*vapour pressure deficit - new 040507;
es=0.6108*exp(17.27*temperature/(temperature+237.3)); *eq12;
ea=humidity/100*es; *eq17;
vpd=es-ea;

*radiation;
Gsc=0.082;
pi=3.141592654;
dr=1+0.033*cos(2*pi/365*day);  *eq23;
de=0.409*sin(2*pi/365*day-1.39);  *eq24;
radians=pi/180*latitude;  *eq22;
ws=arcos(-tan(radians)*tan(de));  *eq25;
Ra= 24*60/pi*Gsc*dr*(ws*sin(radians)*sin(de)+cos(radians)*cos(de)*sin(ws));    *eq21;
Radevap=Ra/lambda; 
Daylight=24/pi*ws;  *eq34;
Sunlight=1-cloudiness; *oa 20040120;
Rs=(0.25+0.5*sunlight)*Ra;  *eq35 if solar rad not measured;
Rso=(0.75+0.00002*altitude)*Ra;  *eq37;
Albedo=0.23;
Rns=(1-albedo)*Rs;   *eq38;
TmeanK=273.15+temperature;*20040120;
SBolz=4.903*10**(-9);
RsRso=min(1,Rs/Rso);
Rnl=SBolz*TmeanK**4*(0.34-0.14*ea**0.5)*(1.35*RsRso-0.35); *eq39;
Rn=Rns-Rnl;

Delta=(4098*(0.6108*exp(17.27*temperature/(temperature+237.3)))/((temperature+237.3)**2));  *eq13;

Etotal=0.408*delta*Rn + gamma*900/(temperature+273)*vind2m*vpd; *eq6 page 65;
Etonam=delta+gamma*(1+0.34*vind2m); *eq6 page 65;
Eto= Etotal/ Etonam; *eq6 page 65;

if Eto<0 then do; Eto=0; end;

/*calculating GAI;
if ctype='Fallow' then do; GAImax=1; GAIbase=0; varians=800; end;
if ctype='Green_fallow' then do; GAImax =3; GAIbase=1; varians=800; end;
if ctype='Ley' then do; GAImax =5; GAIbase=2; varians=800; end; 
if ctype='Root_crops' then do; start=start+10; GAImax =3; GAIbase=0; varians=350; end;*germinating;
if ctype='Seed_ley' then do; start=start+10; GAImax =3; GAIbase=0; varians=800; end;*germinating;
if ctype='Spring_cereals' then do; start=start+10; GAImax =3; GAIbase=0; varians=300; end;*germinating;
if ctype='Spring_oilseed' then do; start=start+10; GAImax =3; GAIbase=0; varians=250; end;*germinating;
if ctype='Winter_cereals' then do; GAImax =5; GAIbase=0.5; varians=500; end;
if ctype='Winter_oilseed' then do; start=start+10; GAImax =5; GAIbase=1; varians=400; end;
*/

middle= start+(stop-start)/2;*Changed OA 20061214;
GAI=max(GAIbase,GAImax*EXP(-((day-middle)**2)/(2*varians)));
*Changed date to day 20061020;

*water balance;
kc=1.3-0.5*exp(-0.17*GAI);*new 20060904;

etc=Eto*kc;
inter=min(precipitation,etc,0.2*GAI); *interception;
if day=1 then do; water = tfield*L; end;
epot=(etc-inter); 

theta=water0/L; *Volumetric water fraction;

if theta ge tfield | theta= . then do; theta=tfield-0.000001; end; 
*Kludge to avoid Kr calc problems OA 021110 ************************;

alfa=0.7; *twilt multiplier; 
Kr=max(0,(1-(0.9*tfield-theta)/(0.9*tfield-alfa*twilt))**2);*20061023;
if Kr>1 then do; Kr=1; end;
actevapo=epot*kr; 

if day>1 then do; water=water0+precipitation-actevapo-inter; end;*021111 -  changed;

if water lt 0 then do;water=0;end;
if water gt tfield*L then do; water=tfield*L;end;
* assume saturated in water when start - in Sweden temp in any case
will give re close to 0;

*water response function; 
*20040917;
rs=0.5;
rwp=0.15;
*topt=0.9*tfield;
topt=min(tfield, 0.6*porosity);*20061023;
if theta>topt then do; re_wat=(1-rs)*(theta-topt)/(topt-porosity)+1; end;
if theta<twilt then do; re_wat=rwp*theta/twilt; end;
if twilt<=theta<=topt then do; re_wat=(1-rwp)*(theta-twilt)/(topt-twilt)+rwp; end;
if re_wat>1 then do; re_wat=1; end;
if re_wat<0 then do; re_wat=0; end;
if bd=. then do;re_wat=.; end;*20040508 if missing soil pars eg bd;
*transforming air temperature into soil temperature;
z=L/20; * Midpoint soil depth in cm;*When L=300mm z=15;

*AIRSOIL start; *from air temp to soil temperature, input temperature, day nr;
*according to Ktterer and Andrn, 2006 for mineral soils;
s1=0.95; s2=0.4; LAIref=3; LAI=0.8*GAI;
kz=0.017; klai=0.15; att=0.24;


if temperature<0 then do; Tsurface=0.2*temperature; end;
if temperature>=0 then do; Tsurface=temperature*(s1+(1-s1)*exp(-s2*(LAI-LAIref))); end;

if day=1 then do; soiltemp=0;end;
if day>1 then do; soiltemp=soiltemp0 + (Tsurface - soiltemp0)*att*exp(-kz*z)*exp(-klai*LAI); end;
soiltemp0= soiltemp;
*AIRSOIL stop; *output soiltemp;

water0 = water;

*temperature response function; *Ktterer et al 1998 ;
tmin=-3.78 ;
re_temp=(soiltemp-tmin)**2/((30-tmin))**2; 

*And, finally, re;

reu=re_temp*re_wat*re_cult; *02111 021201;
run;
*+++++++++++++++++++++++++++++++++++++++++++ WATER MOD LOOP END;
proc summary nway data=calc1;
class year accday day; *makes table with annual mean re;
var Eto re_temp re_wat ;
output out=bb mean=;
run;



PROC EXPORT DATA= WORK.calc1 
            OUTFILE= "C:\MIR\thomk\ICBM\Olle2013\mother_v2_1970-1999.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="reclim_Ultuna1970-1999.xls"; 
RUN;
